@@ -16,6 +16,7 @@ import logging
 import re
 import warnings
 import weakref
+import time
 
 from celery.signals import task_postrun
 from django.conf import settings as dj_settings
@@ -413,7 +414,7 @@ class ChartMixin(object):
             results[item] = []
             for point in xrange(points, -1, -1):
                 dt = today - datetime.timedelta(**{d_type: point * modifier})
-                results[item].append((int((dt).strftime('%s')) * 1000, tsdata.get(dt, 0)))
+                results[item].append((int(time.mktime((dt).timetuple())) * 1000, tsdata.get(dt, 0)))
 
         if key is None:
             return results[None]
@@ -647,7 +648,10 @@ class GroupManager(BaseManager, ChartMixin):
         if user_ident:
             self.record_affected_user(group, user_ident)
 
-        self.add_tags(group, tags)
+        try:
+            self.add_tags(group, tags)
+        except Exception, e:
+            logger.exception('Unable to record tags: %s' % (e,))
 
         return group, is_new, is_sample
 
@@ -674,7 +678,11 @@ class GroupManager(BaseManager, ChartMixin):
         date = group.last_seen
 
         for key, value in itertools.ifilter(lambda x: bool(x[1]), tags):
-            if not value or len(value) > MAX_TAG_LENGTH:
+            if not value:
+                continue
+
+            value = unicode(value)
+            if len(value) > MAX_TAG_LENGTH:
                 continue
 
             # TODO: FilterKey and FilterValue queries should be create's under a try/except
