@@ -39,6 +39,7 @@ from sentry.constants import (STATUS_LEVELS, MEMBER_TYPES,  # NOQA
 from sentry.manager import GroupManager, ProjectManager, \
   MetaManager, InstanceMetaManager, SearchDocumentManager, BaseManager, \
   UserOptionManager, FilterKeyManager, TeamManager
+from sentry.signals import buffer_incr_complete
 from sentry.utils import cached_property, \
   MockDjangoRequest
 from sentry.utils.models import Model, GzippedDictField, update
@@ -389,6 +390,42 @@ class MessageBase(Model):
             return self.culprit
         return truncatechars(self.message.splitlines()[0], 100)
 
+    @property
+    def user_ident(self):
+        """
+        The identifier from a user is considered from several interfaces.
+
+        In order:
+
+        - User.id
+        - User.email
+        - User.username
+        - Http.env.REMOTE_ADDR
+
+        """
+        user_data = self.data.get('sentry.interfaces.User')
+        if user_data:
+            ident = user_data.get('id')
+            if ident:
+                return 'id:%s' % (ident,)
+
+            ident = user_data.get('email')
+            if ident:
+                return 'email:%s' % (ident,)
+
+            ident = user_data.get('username')
+            if ident:
+                return 'username:%s' % (ident,)
+
+        http_data = self.data.get('sentry.interfaces.Http')
+        if http_data:
+            if 'env' in http_data:
+                ident = http_data['env'].get('REMOTE_ADDR')
+                if ident:
+                    return 'ip:%s' % (ident,)
+
+        return None
+
 
 class Group(MessageBase):
     """
@@ -396,6 +433,7 @@ class Group(MessageBase):
     """
     status = models.PositiveIntegerField(default=0, choices=STATUS_LEVELS, db_index=True)
     times_seen = models.PositiveIntegerField(default=1, db_index=True)
+    users_seen = models.PositiveIntegerField(default=0, db_index=True)
     last_seen = models.DateTimeField(default=timezone.now, db_index=True)
     first_seen = models.DateTimeField(default=timezone.now, db_index=True)
     resolved_at = models.DateTimeField(null=True, db_index=True)
@@ -806,6 +844,28 @@ class LostPasswordHash(models.Model):
             logger.exception(e)
 
 
+class AffectedUserByGroup(Model):
+    """
+    Stores a count of how many times a ``Group`` has affected
+    a user.
+    """
+    project = models.ForeignKey(Project)
+    group = models.ForeignKey(Group)
+    ident = models.CharField(max_length=200)
+    times_seen = models.PositiveIntegerField(default=0)
+    last_seen = models.DateTimeField(default=timezone.now, db_index=True)
+    first_seen = models.DateTimeField(default=timezone.now, db_index=True)
+
+    objects = BaseManager()
+
+    class Meta:
+        unique_together = (('project', 'ident', 'group'),)
+
+    def __unicode__(self):
+        return u'group_id=%s, times_seen=%s, ident=%s' % (self.group_id, self.times_seen,
+                                                          self.ident)
+
+
 ### django-indexer
 
 
@@ -936,6 +996,22 @@ def set_language_on_logon(request, user, **kwargs):
     if language and hasattr(request, 'session'):
         request.session['django_language'] = language
 
+
+@buffer_incr_complete.connect(sender=AffectedUserByGroup, weak=False)
+def record_user_count(filters, created, **kwargs):
+    from sentry import app
+
+    if not created:
+        # if it's not a new row, it's not a unique user
+        return
+
+    app.buffer.incr(Group, {
+        'users_seen': 1,
+    }, {
+        'id': filters['group'].id,
+    })
+
+
 # Signal registration
 post_syncdb.connect(
     create_default_project,
@@ -972,6 +1048,10 @@ pre_delete.connect(
     dispatch_uid="remove_key_for_team_member",
     weak=False,
 )
-user_logged_in.connect(set_language_on_logon)
+user_logged_in.connect(
+    set_language_on_logon,
+    dispatch_uid="set_language_on_logon",
+    weak=False
+)
 
 add_introspection_rules([], ["^social_auth\.fields\.JSONField"])
