@@ -55,6 +55,8 @@ urlpatterns = patterns('',
         name='sentry-manage-team'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/remove/$', teams.remove_team,
         name='sentry-remove-team'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/$', teams.manage_team_members,
+        name='sentry-manage-team-members'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/new/$', teams.new_team_member,
         name='sentry-new-team-member'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/(?P<member_id>\d+)/edit/$', teams.edit_team_member,
@@ -69,7 +71,10 @@ urlpatterns = patterns('',
         name='sentry-remove-pending-team-member'),
     url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/pending/(?P<member_id>\d+)/reinvite/$', teams.reinvite_pending_team_member,
         name='sentry-reinvite-pending-team-member'),
-    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/new/$', teams.create_new_team_project, name='sentry-new-team-project'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/$', teams.manage_team_projects,
+        name='sentry-manage-team-projects'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/new/$', teams.create_new_team_project,
+        name='sentry-new-team-project'),
     url(r'^accept/(?P<member_id>\d+)/(?P<token>\w+)/$', teams.accept_invite,
         name='sentry-accept-invite'),
 
